@@ -1,5 +1,5 @@
 (*
- * Copyright 2003-2006 The Savonet team
+ * Copyright 2003-2011 The Savonet team
  *
  * This file is part of Ocaml-vorbis.
  *
@@ -25,7 +25,7 @@
   * @author Samuel Mimram, Julien Cristau, David Baelde
   *)
 
-(* $Id: vorbis.mli 6403 2009-02-17 18:23:30Z metamorph68 $ *)
+(* $Id$ *)
 
 (** {1 Exceptions} *)
 
@@ -37,18 +37,9 @@ exception False
 (** Some parameters are invalid for this function. *)
 exception Invalid_parameters
 
-(** The given quality in invalid. *)
-exception Invalid_quality
-
-(** The given bitrate is invalid. *)
-exception Invalid_bitrate
-
 (** The given number of channels is invalid. *)
 exception Invalid_channels
 
-(** The given sampling frequency is invalid. *)
-exception Invalid_sample_freq
-
 (** Invalid setup request, e.g. out of range argument. *)
 exception Invalid_argument
 
@@ -90,6 +81,10 @@ exception Unknown_error of int
 (** Error while converting utf8. *)
 exception Utf8_failure of string
 
+(** Return a string representation
+  * of an exception *)
+val string_of_exc : exn -> string option
+
 (** {1 Useful types} *)
 
 (** Index of a logical bitstream. The special value -1 means the physical
@@ -143,7 +138,13 @@ sig
     * in the initial pages. *)
   val headerout_packetout : t -> (string * string) list -> Ogg.Stream.packet*Ogg.Stream.packet*Ogg.Stream.packet
 
-  (** Encode a buffer of PCM data. *)
+  (** Get the number of audio channels expected by 
+    * the encoder. *)
+  val get_channels : t -> int
+
+  (** Encode a buffer of PCM data. 
+    * The PCM data array must have at least the expected
+    * number of channels. Otherwise, the function raises [Invalid_channels]. *)
   val encode_buffer_float : t -> Ogg.Stream.t -> float array array -> int -> int -> unit
 
   (** Convert a granulepos to absolute time in seconds. The granulepos is
@@ -197,22 +198,20 @@ sig
     (** Internal state of a decoder. *)
     type t
   
-    (** [create read_func seek_func close_func tell_func params] opens a
+    (** [create read_func seek_func tell_func params] opens a
       * stream like [openfile] for decoding but callbacks are used to
       * manipulate the data. [read_func] should return the requested amount of bytes
       * (or less if it is the end of file), [seek_funk] should return 0 if the seek
-      * was ok or -1 if the stream is not seekable, [close_func] should close the
-      * stream, and [tell_func] should return the current offset or -1 if there is
-      * no notion of offset in the stream. Raises: [Read_error], [Not_vorbis],
-      * [Version_mismatch], [Bad_header], [Internal_fault].
+      * was ok or -1 if the stream is not seekable, [tell_func] should return the current 
+      * offset or -1 if there is no notion of offset in the stream. 
+      * Raises: [Read_error], [Not_vorbis], [Version_mismatch], [Bad_header], [Internal_fault].
       *)
-    val create : (int -> string * int) -> (int -> Unix.seek_command -> int) -> (unit -> unit) -> (unit -> int) -> t
+    val create : (int -> string * int) -> (int -> Unix.seek_command -> int) -> (unit -> int) -> t
   
     (** Open a vorbis file for decoding. *)
-    val openfile : string -> t
-  
-    val openfile_with_fd : string -> t * Unix.file_descr
-  
+    val openfile : string -> t * Unix.file_descr
+    val openfile_with_fd : Unix.file_descr -> t
+ 
     (** [decode_float dec buff ofs len] decodes [len] samples in each channel and puts
       * the result in [buff] starting at position [ofs].
       * @raise Hole_in_data if there was an interruption of the data.
@@ -225,11 +224,6 @@ sig
     (** Same as [decode_float] but decodes to integers. *)
     val decode : t -> ?big_endian:bool -> ?sample_size:int -> ?signed:bool -> string -> int -> int -> int
   
-    (** Close a decoder. Every decoder must be closed after use and must not be
-      * used after it is closed.
-      *)
-    val close : t -> unit
-  
     (** Get the number of logical bitstreams within a physical bitstream. *)
     val streams : t -> int
   
